==> mahara_1.4.0.orig.tar.gz: mahara-1.4.0/htdocs/lang/en.utf8/collection.php <==
<?php

/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Collections';

$string['about'] = 'About';
$string['access'] = 'Access';
$string['accesscantbeused'] = 'Access override not saved. The chosen pages access (Secret URL) can\'t be used for multiple pages.';
$string['accessoverride'] = 'Access override';
$string['accesssaved'] = 'Collection access saved successfully.';
$string['accessignored'] = 'Some secret URL access types were ignored.';
$string['add'] = 'Add';
$string['addviews'] = 'Add pages';
$string['addviewstocollection'] = 'Add pages to collection';
$string['back'] = 'Back';
$string['cantdeletecollection'] = 'You cannot delete this collection.';
$string['canteditdontown'] = 'You can\'t edit this collection because you don\'t own it.';
$string['collection'] = 'collection';
$string['Collection'] = 'Collection';
$string['collections'] = 'Collections';
$string['Collections'] = 'Collections';
$string['collectionaccess'] = 'Collection access';
$string['collectionaccesseditedsuccessfully'] = 'Collection access saved successfully';
$string['collectioneditaccess'] = 'You are editing access for %d pages in this Collection';
$string['collectionconfirmdelete'] = 'Pages in this collection will not be deleted.  Are you sure you wish to delete this collection?';
$string['collectioncreatedsuccessfully'] = 'Collection created successfully.';
$string['collectioncreatedsuccessfullyshare'] = 'Your collection has been created successfully.  Share your collection with others using the access links below.';
$string['collectiondeleted'] = 'Collection deleted successfully.';
$string['collectiondescription'] = 'A Collection is a set of pages that are linked to one another and have the same access permissions.  You can create as many collections as you like, but a page cannot appear in more than one collection.';
$string['confirmcancelcreatingcollection'] = 'This Collection has not been completed. Do you really want to cancel?';
$string['collectionsaved'] = 'Collection saved successfully.';
$string['created'] = 'Created';
$string['deletecollection'] = 'Delete collection';
$string['deletespecifiedcollection'] = 'Delete collection \'%s\'';
$string['deletingcollection'] = 'Deleting collection';
$string['deleteview'] = 'Remove page from collection';
$string['description'] = 'Collection description';
$string['editcollection'] = 'Edit collection';
$string['editingcollection'] = 'Editing Collection';
$string['edittitleanddesc'] = 'Edit Title and Description';
$string['editviews'] = 'Edit Collection pages';
$string['editviewaccess'] = 'Edit page access';
$string['editaccess'] = 'Edit Collection Access';
$string['emptycollectionnoeditaccess'] = 'You cannot edit access to empty collections.  Add some pages first.';
$string['emptycollection'] = 'Empty collection';
$string['manageviews'] = 'Manage pages';
$string['name'] = 'Collection name';
$string['newcollection'] = 'New Collection';
$string['nocollectionsaddone'] = 'No collections yet. %sAdd one%s!';
$string['nooverride'] = 'No override';
$string['noviewsavailable'] = 'No pages are available to add.';
$string['noviewsaddsome'] = 'No pages in collection. %sAdd some!%s';
$string['noviews'] = 'No pages.';
$string['overrideaccess'] = 'Override Access';
$string['potentialviews'] = 'Potential pages';
$string['saveapply'] = 'Apply & Save';
$string['savecollection'] = 'Save collection';
$string['update'] = 'Update';
$string['usecollectionname'] = 'Use collection name?';
$string['usecollectionnamedesc'] = 'If you wish to use the collection name instead of the Block Title leave this checked.';
$string['viewaddedtocollection'] = 'Page added to collection. Collection updated to include access from new page.';
$string['viewcollection'] = 'View Collection Details';
$string['viewcount'] = 'Pages';
$string['viewremovedsuccessfully'] = 'Page removed successfully.';
$string['viewnavigation'] = 'Page navigation bar';
$string['viewnavigationdesc'] = 'Add a horizontal navigation bar to every page in this collection by default.';
$string['viewsaddedtocollection'] = 'Pages added to collection. Collection updated to include access from new pages.';
$string['viewstobeadded'] = 'Pages to be added';
$string['viewconfirmremove'] = 'Are you sure you wish to remove this page from the collection?';

==> mahara_1.5.1.orig.tar.gz: mahara-1.5.1/htdocs/lang/en.utf8/collection.php <==
<?php

/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Collections';

$string['about'] = 'About';
$string['access'] = 'Access';
$string['accesscantbeused'] = 'Access override not saved. The chosen pages access (Secret URL) cannot be used for multiple pages.';
$string['accessoverride'] = 'Access override';
$string['accesssaved'] = 'Collection access saved successfully.';
$string['accessignored'] = 'Some secret URL access types were ignored.';
$string['add'] = 'Add';
$string['addviews'] = 'Add pages';
$string['addviewstocollection'] = 'Add pages to collection';
$string['back'] = 'Back';
$string['cantdeletecollection'] = 'You cannot delete this collection.';
$string['canteditdontown'] = 'You cannot edit this collection because you do not own it.';
$string['collection'] = 'collection';
$string['Collection'] = 'Collection';
$string['collections'] = 'Collections';
$string['Collections'] = 'Collections';
$string['collectionaccess'] = 'Collection access';
$string['collectionaccesseditedsuccessfully'] = 'Collection access saved successfully';
$string['collectioneditaccess'] = 'You are editing access for %d pages in this collection';
$string['collectionconfirmdelete'] = 'Pages in this collection will not be deleted. Are you sure you wish to delete this collection?';
$string['collectioncreatedsuccessfully'] = 'Collection created successfully.';
$string['collectioncreatedsuccessfullyshare'] = 'Your collection has been created successfully. Share your collection with others using the access links below.';
$string['collectiondeleted'] = 'Collection deleted successfully.';
$string['collectiondescription'] = 'A collection is a set of pages that are linked to one another and have the same access permissions. You can create as many collections as you like, but a page cannot appear in more than one collection.';
$string['collectiontitle'] = 'Collection title';
$string['confirmcancelcreatingcollection'] = 'This collection has not been completed. Do you really want to cancel?';
$string['collectionsaved'] = 'Collection saved successfully.';
$string['copyacollection'] = 'Copy a collection';
$string['created'] = 'Created';
$string['deletecollection'] = 'Delete collection';
$string['deletespecifiedcollection'] = 'Delete collection \'%s\'';
$string['deletingcollection'] = 'Deleting collection';
$string['deleteview'] = 'Remove page from collection';
$string['description'] = 'Collection description';
$string['editcollection'] = 'Edit collection';
$string['editingcollection'] = 'Editing collection';
$string['edittitleanddesc'] = 'Edit title and description';
$string['editviews'] = 'Edit collection pages';
$string['editviewaccess'] = 'Edit page access';
$string['editaccess'] = 'Edit collection access';
$string['emptycollectionnoeditaccess'] = 'You cannot edit access to empty collections. Add some pages first.';
$string['emptycollection'] = 'Empty collection';
$string['manageviews'] = 'Manage pages';
$string['name'] = 'Collection name';
$string['newcollection'] = 'New collection';
$string['nocollectionsaddone'] = 'No collections yet. %sAdd one%s!';
$string['nooverride'] = 'No override';
$string['noviewsavailable'] = 'No pages are available to add.';
$string['noviewsaddsome'] = 'No pages in collection. %sAdd some!%s';
$string['noviews'] = 'No pages.';
$string['overrideaccess'] = 'Override access';
$string['potentialviews'] = 'Potential pages';
$string['saveapply'] = 'Apply and save';
$string['savecollection'] = 'Save collection';
$string['update'] = 'Update';
$string['usecollectionname'] = 'Use collection name?';
$string['usecollectionnamedesc'] = 'If you wish to use the collection name instead of the Block title leave this checked.';
$string['viewaddedtocollection'] = 'Page added to collection. Collection updated to include access from new page.';
$string['viewcollection'] = 'View collection details';
$string['viewcount'] = 'Pages';
$string['viewremovedsuccessfully'] = 'Page removed successfully.';
$string['viewnavigation'] = 'Page navigation bar';
$string['viewnavigationdesc'] = 'Add a horizontal navigation bar to every page in this collection by default.';
$string['viewsaddedtocollection'] = 'Pages added to collection. Collection updated to include access from new pages.';
$string['viewstobeadded'] = 'Pages to be added';
$string['viewconfirmremove'] = 'Are you sure you wish to remove this page from the collection?';
$string['collectioncopywouldexceedquota'] = 'Copying this collection would exceed your file quota.';
$string['copiedpagesblocksandartefactsfromtemplate'] = 'Copied %d pages, %d blocks and %d artefacts from %s';
$string['copiedblogpoststonewjournal'] = 'Copied journal posts have been put into a new separate journal.';
$string['by'] = 'by';
$string['copycollection'] = 'Copy collection';
